#!/usr/bin/perl

use Test::More qw(no_plan);

use FindBin qw($Bin);
use lib "$Bin/lib", "$Bin/../lib";
use lib "/usr/local/nagios/lib", "/usr/local/nagios/etc", "/usr/local/nagios/t/lib";
use strict;
use Opsview;
use Opsview::Hosttemplate;
use Opsview::Test;
use Opsview::TestCGI;

my $sth;
my $dbh = Opsview->db_Main;
ok( defined $dbh, "Connect to db" );

my $rc;

# Tests on servicechecks
my $rows = $dbh->selectrow_array("SELECT COUNT(*) FROM servicechecks");
$rc = post('type=servicecheck action=new name="new check" category_new="fluffy" servicegroup_new="notifyme" plugin="check_http"');
ok( $rc == 0, "Added new servicecheck" );
ok( $dbh->selectrow_array("SELECT COUNT(*) FROM servicechecks") == ( $rows + 1 ), "and into database" );

# Remove these tests as duplicate create will just be sync'd. Also no servicegroup will not fail as default servicegroup used
#$rc = post('type=servicecheck action=new name="new check" category_new="fluffy" servicegroup_new="notifyme" plugin="check_http"');
#ok( $rc != 0, "Adding same servicecheck, expect failure" );
#$rc = post('type=servicecheck action=new name="newer check" category_new="fluffy" plugin="check_http"');
#ok( $rc != 0, "Adding servicecheck without servicegroup" );

# We do this, but we don't run any tests about it as we no longer use categories
$rc = post('type=servicecheck action=new name="newer check" category="bumpy" category_new="fluffy" servicegroup_new="notifyme" plugin="check_tcp"');

$rc = post('type=servicecheck action=new name="bump check" servicegroup=1 servicegroup_new="donotnotifyme" category=dummy plugin="check_tcp"');
ok( $rc == 0, "Using servicegroup_new over servicegroup" );
ok( $dbh->selectrow_array("SELECT COUNT(*) FROM servicechecks") == ( $rows + 3 ), "Added into DB" );
ok( $dbh->selectrow_array("SELECT servicegroups.name FROM servicegroups,servicechecks WHERE servicegroups.id=servicechecks.servicegroup AND servicechecks.name='bump check'") eq "donotnotifyme", "Right in DB" );

my $sgid = $dbh->selectrow_array("SELECT id FROM servicegroups WHERE name='donotnotifyme'");
$rc = post("type=servicecheck action=new name=quiet servicegroup=$sgid category=dummy plugin=check_tcp");
ok( $rc == 0, "Using just servicegroup id" );
ok( $dbh->selectrow_array("SELECT COUNT(*) FROM servicechecks") == ( $rows + 4 ), "Added into DB" );
ok( $dbh->selectrow_array("SELECT servicegroup FROM servicechecks WHERE name='quiet'") == $sgid, "Right in DB" );

# Test below must be "eq" to know if the value is set correctly
cmp_ok( $dbh->selectrow_array("SELECT checktype FROM servicechecks WHERE name='quiet'"), 'eq', "1", "checktype is set to activecheck" );

$rc = post('type=servicecheck action=new name=groupings category=red servicegroup=1 plugin="check_tcp"');
ok( $rc == 0, "Using just category" );
ok( $dbh->selectrow_array("SELECT COUNT(*) FROM servicechecks") == ( $rows + 5 ), "Added into DB" );

my $scid = $dbh->selectrow_array("SELECT id FROM servicechecks WHERE name='quiet'");
ok( $dbh->selectrow_array("SELECT invertresults FROM servicechecks WHERE id=$scid") == 0, "No invertresults" );

$rc = post("type=servicecheck action=edit id=$scid invertresults=1");
ok( $rc == 0,                                                                             "Edit to set invertresults" );
ok( $dbh->selectrow_array("SELECT invertresults FROM servicechecks WHERE id=$scid") == 1, "Invertresults set in DB" );

$rc = post("type=servicecheck action=edit id=$scid");
ok( $rc == 0,                                                                             "Edit to remove invertresults" );
ok( $dbh->selectrow_array("SELECT invertresults FROM servicechecks WHERE id=$scid") == 0, "Invertresults unset in DB" );

$rc = post("type=servicecheck action=delete id=$scid");
ok( $rc == 0, "Deleting servicecheck" );
ok( $dbh->selectrow_array("SELECT COUNT(*) FROM servicechecks") == ( $rows + 4 ), "Deleted from DB" );

$rc = post("type=servicecheck action=new name=notifications notification_interval=7 notification_period=1 plugin=check_http category_new=notone servicegroup_new=nottwo");
ok( $rc == 0,                                                                                                 "Can add notification_interval and notification_period" );
ok( $dbh->selectrow_array("SELECT COUNT(*) FROM servicechecks WHERE name='notifications'") == 1,              "In DB" );

$scid = $dbh->selectrow_array("SELECT id FROM servicechecks WHERE name='notifications'");
$rc   = post("type=servicecheck action=edit id=$scid notification_interval=9 notification_period=2");
ok( $rc == 0,                                                                                     "Can amend notification_interval and notification_period" );

$rc = post("type=servicecheck action=edit id=$scid notification_interval= notification_period=");
ok( $rc == 0, "Can set notifications to null values" );

my $scid1 = $dbh->selectrow_array("SELECT id FROM servicechecks WHERE name='newer check'");
my $scid2 = $dbh->selectrow_array("SELECT id FROM servicechecks WHERE name='groupings'");

# Tests on contacts
my $num_of_contacts = $dbh->selectrow_array("SELECT COUNT(*) FROM contacts");
$rc = post('type=contact action=new fullname="James Peel" name="jamespeel" email="here"');
ok( $rc == 0, "Added new contact" );
$rc = post('type=contact action=new fullname="James Peel" name="jamespeel" email="here"');
ok( $rc == 0, "Added same contact, now synchronises based on username" );
$rc = post('type=contact action=new name="bob"');
ok( $rc != 0,                                                                       "Missing name parameter" );
ok( $dbh->selectrow_array("SELECT COUNT(*) FROM contacts") == $num_of_contacts + 1, "Only one row created" );

$rc = post('type=contact action=new fullname=bob');
ok( $rc != 0,                                                                       "Missing username parameter" );
ok( $dbh->selectrow_array("SELECT COUNT(*) FROM contacts") == $num_of_contacts + 1, "Only one row created" );

$rc = post('type=contact action=new fullname="Ton Voon" email="ton.voon@altinity.com" mobile="07931365796" name="tonvoon" service_notification_options=w service_notification_options=r host_notification_options=u host_notification_options=r');
ok( $rc == 0,                                                                       "Added new contact" );
ok( $dbh->selectrow_array("SELECT COUNT(*) FROM contacts") == $num_of_contacts + 2, "Two rows" );

my $id = $dbh->selectrow_array("SELECT id FROM contacts WHERE fullname='Ton Voon'");

$rc = post( 'type=contact action=edit id=' . $id . ' service_notification_options=w service_notification_options=r service_notification_options=c service_notification_options=n service_notification_options=f host_notification_options=d' );

$rc = post("type=contact action=edit id=$id notification_period=2");
ok( $rc == 0, "Edited contact" );

