#!/usr/bin/perl

use warnings;
use strict;
use FindBin qw($Bin);
use lib "$Bin/../lib";

use lib "/usr/local/nagios/lib", "/usr/local/nagios/etc", "/usr/local/nagios/t/lib";

use Test::More qw(no_plan);
use Test::Deep;

use Test::WWW::Mechanize::Catalyst qw(Opsview::Web);
use lib "$Bin/lib";
use Opsview::TestUtils;

my $mech = Test::WWW::Mechanize::Catalyst->new;

log_in( $mech, 'admin', 'initial' );
witter('Check comments on "Monitoring Servers" hostgroup');

$mech->get_ok('http://localhost/info/hostgroup/2');
$mech->content_like(qr/No comments currently entered for this item./);

$mech->get_ok('http://localhost/info/hostgroup/2/edit');
$mech->form_name('comments');
$mech->field( 'content' => 'Comment added by testing' );
$mech->click('submit');
$mech->get_ok('http://localhost/info/hostgroup/2');
$mech->content_like(qr/Comment added by testing/);

# Check angle brackets are escaped
$mech->get_ok('http://localhost/info/hostgroup/2/edit');
$mech->form_name('comments');
$mech->field( 'content' => 'This contains a <script>alert("Helpme!")</script>' );
$mech->click('submit');
$mech->get_ok('http://localhost/info/hostgroup/2');
$mech->content_contains( 'This contains a &lt;script&gt;alert', "Escaped for info" );

# Check auto update preview html output also escapes angle brackets
$mech->post( "/info/get_html", { content => 'This contains a <script>alert("Helpme!")</script>' } );
$mech->content_contains( 'This contains a &lt;script&gt;alert', "Escaped for auto update preview" );

$mech->post( "/info/get_html", { content => '' } );
$mech->content_contains( 'No comments currently entered for this item' );

$mech->post( "/info/get_html", { content => '   ' } );
$mech->content_contains( 'No comments currently entered for this item', 'Still get this message when spaces entered' );

# Cleared - tests assumes true later
$mech->get_ok('http://localhost/info/hostgroup/2/edit');
$mech->form_name('comments');
$mech->field( 'content' => '' );
$mech->click('submit');
$mech->get_ok('http://localhost/info/hostgroup/2');
$mech->content_like(qr/No comments currently entered for this item./);

log_out($mech);

log_in( $mech, 'nonadmin', 'nonadmin' );

$mech->get_ok('http://localhost/info/hostgroup/2');
$mech->content_like(qr/No comments currently entered for this item./);

$mech->get_ok('http://localhost/info/hostgroup/2/edit');
$mech->content_unlike(qr/input type=submit/i);

log_out($mech);

log_in( $mech, 'somehosts', 'somehosts' );

$mech->get_ok('http://localhost/info/hostgroup/2');
$mech->content_like(qr/No comments currently entered for this item./);

$mech->get_ok('http://localhost/info/hostgroup/2/edit');
$mech->content_unlike(qr/input type=submit/i);

log_out($mech);

log_in( $mech, 'readonly', 'readonly' );

$mech->get_ok('http://localhost/info/hostgroup/2');
$mech->content_like(qr/No comments currently entered for this item./);

$mech->get_ok('http://localhost/info/hostgroup/2/edit');
$mech->content_unlike(qr/input type=submit/i);

log_out($mech);
