#!/usr/bin/perl
# Test rest

use warnings;
use strict;
use FindBin qw($Bin);
use lib "$Bin/../lib";

use lib "/usr/local/nagios/lib", "/usr/local/nagios/etc", "/usr/local/nagios/t/lib";

use Test::More qw(no_plan);
use Test::Deep;
use Test::LongString;

use Opsview::Test qw(opsview);
use Test::WWW::Mechanize::Catalyst qw(Opsview::Web);

use lib "$Bin/lib";
use Opsview::TestUtils;

use Data::Dump qw(dump);

my $content;
my $ua = Test::WWW::Mechanize::Catalyst->new( stack_depth => 0 );

my $res_data;

rest_log_in( $ua, "admin", "initial" );


# Now for some magic! We're going to synchronise all contact objects
$ua->put( "http://localhost/rest/config/contact?synchronise=1", Content => '{ list => [ { id => 1, fullname => "c1" }, { id => 2, fullname => "c2" }, { id => 3, fullname => "c3" }, { id => 4, fullname => "c4" } ] }' );
is( $ua->status, 200, "Sync was successful" );
$res_data = eval $ua->content;
is( $res_data->{objects_updated}, 4, "Four objects updated" );

$ua->get( "http://localhost/rest/config/contact?cols=id,fullname" );
is( $ua->status, 200, "Got list of contacts" );
$res_data = eval $ua->content;
is( $res_data->{summary}->{allrows}, 4, "Only 4 contacts now! So syncing works!" );


# Try to delete. This should roll back due to requiring at least 1 ADMINACCESS person
$ua->put( "http://localhost/rest/config/contact?synchronise=1", Content => '{ list => [] }' );
is( $ua->status, 400, "Sync failed correctly" );
$res_data = eval $ua->content;
is( $res_data->{message}, "Rollback: Error when trying to delete old objects in a synchronise", "Delete error caught" ) 
  || diag("Full content: ".$ua->content);
like( $res_data->{detail}, qr/DBIx::Class::Row::throw_exception\(\): CannotDeleteAllAdminAccess/, "Correct error in deletion" );

1;
