#!/usr/bin/perl
# Test rest via XML

use warnings;
use strict;
use FindBin qw($Bin);
use lib "$Bin/../lib";

use lib "/usr/local/nagios/lib", "/usr/local/nagios/etc", "/usr/local/nagios/t/lib";

use Test::More qw(no_plan);
use Test::Deep;
use Test::LongString;

use Opsview::Test qw(opsview);
use Test::WWW::Mechanize::Catalyst qw(Opsview::Web);

use lib "$Bin/lib";
use Opsview::TestUtils;

use Data::Dump qw(dump);

my $content;
my $ua = Test::WWW::Mechanize::Catalyst->new( stack_depth => 0 );

rest_log_in( $ua, "admin", "initial" );
$ua->add_header( 'Content-type' => "text/xml" );
my $url_prefix = "http://localhost:3000";

# List result
$ua->get_ok( "$url_prefix/rest/config/host?rows=1&page=1&cols=icon,hosttemplates,ip,name,id,hostgroup,http_admin_port", "Only get 1st page of hosts" );
my $res_data = $ua->content;
my $expected = qq{<opsview>
  <list>
    <item name="cisco"
          id="7"
          ip="192.168.10.20"
          ref="/rest/config/host/7">
      <hostgroup name="Leaf"
                 ref="/rest/config/hostgroup/4" />
      <hosttemplates>
        <item name="Cisco Mgt"
              ref="/rest/config/hosttemplate/3" />
      </hosttemplates>
      <icon name="SYMBOL - Environment Monitor"
            path="/images/logos/meter_small.png" />
    </item>
  </list>
  <summary allrows="24"
           page="1"
           rows="1"
           totalpages="24"
           totalrows="24" />
</opsview>
};
is_string( $res_data, $expected, "Got expected data for host list" ) || print($res_data);

$ua->get_ok( "$url_prefix/rest/config/host/7", "Get cisco host info" );
$expected = qq{<opsview>
  <object name="cisco"
          alias=""
          check_attempts="2"
          check_interval="0"
          enable_snmp="0"
          flap_detection_enabled="1"
          id="7"
          ip="192.168.10.20"
          nmis_node_type="router"
          notification_interval="0"
          notification_options="u,d,r"
          other_addresses=""
          rancid_connection_type="ssh"
          retry_check_interval="1"
          snmp_community="shouldnotcreate"
          snmp_max_msg_size="0"
          snmp_port="161"
          snmp_version="2c"
          snmpv3_authpassword=""
          snmpv3_privpassword=""
          snmpv3_username=""
          tidy_ifdescr_level="0"
          uncommitted="0"
          use_mrtg="0"
          use_nmis="0"
          use_rancid="0">
    <check_command name="slow ping"
                   ref="/rest/config/hostcheckcommand/1" />
    <check_period name="24x7"
                  ref="/rest/config/timeperiod/1" />
    <hostattributes isEmpty="1" />
    <hostgroup name="Leaf"
               ref="/rest/config/hostgroup/4" />
    <hosttemplates>
      <item name="Cisco Mgt"
            ref="/rest/config/hosttemplate/3" />
    </hosttemplates>
    <icon name="SYMBOL - Environment Monitor"
          path="/images/logos/meter_small.png" />
    <keywords>
      <item name="alphaearly"
            ref="/rest/config/keyword/6" />
      <item name="cisco"
            ref="/rest/config/keyword/2" />
      <item name="cisco_gp1"
            ref="/rest/config/keyword/3" />
    </keywords>
    <monitored_by name="Master Monitoring Server"
                  ref="/rest/config/monitoringserver/1" />
    <notification_period name="24x7"
                         ref="/rest/config/timeperiod/1" />
    <parents>
      <item name="cisco"
            ref="/rest/config/host/7" />
    </parents>
    <rancid_password isNull="1" />
    <rancid_username isNull="1" />
    <rancid_vendor isNull="1" />
    <servicechecks>
      <item name="Another exception"
            ref="/rest/config/servicecheck/82"
            remove_servicecheck="0">
        <event_handler isNull="1" />
        <exception isNull="1" />
        <timed_exception isNull="1" />
      </item>
      <item name="Coldstart"
            ref="/rest/config/servicecheck/79"
            remove_servicecheck="0">
        <event_handler isNull="1" />
        <exception isNull="1" />
        <timed_exception isNull="1" />
      </item>
      <item name="Interface"
            ref="/rest/config/servicecheck/95"
            remove_servicecheck="0">
        <event_handler isNull="1" />
        <exception isNull="1" />
        <timed_exception isNull="1" />
      </item>
      <item name="snmp poll"
            ref="/rest/config/servicecheck/83"
            remove_servicecheck="0">
        <event_handler isNull="1" />
        <exception isNull="1" />
        <timed_exception isNull="1" />
      </item>
      <item name="Test exceptions"
            ref="/rest/config/servicecheck/81"
            remove_servicecheck="0">
        <event_handler isNull="1" />
        <exception isNull="1" />
        <timed_exception isNull="1" />
      </item>
    </servicechecks>
    <snmpv3_authprotocol isNull="1" />
    <snmpv3_privprotocol isNull="1" />
  </object>
</opsview>
};
$res_data = $ua->content;
is_string( $res_data, $expected, "Got hash data for host as expected" ) || print($res_data);


my $input = qq{
<opsview name="cisco"
          alias=""
          check_attempts="2"
          check_interval="0"
          enable_snmp="0"
          flap_detection_enabled="1"
          id="7"
          ip="192.168.10.20"
          nmis_node_type="router"
          notification_interval="0"
          notification_options="u,d,r"
          other_addresses=""
          rancid_connection_type="ssh"
          retry_check_interval="1"
          snmp_community="shouldnotcreate"
          snmp_port="161"
          snmp_version="2c"
          snmpv3_authpassword=""
          snmpv3_privpassword=""
          snmpv3_username=""
          uncommitted="0"
          use_mrtg="0"
          use_nmis="0"
          use_rancid="0">
    <check_command name="slow ping"
                   ref="/rest/config/hostcheckcommand/1" />
    <check_period name="24x7"
                  ref="/rest/config/timeperiod/1" />
    <hostattributes isEmpty="1" />
    <hostgroup name="Leaf"
               ref="/rest/config/hostgroup/4" />
    <hosttemplates>
      <item name="Cisco Mgt"
            ref="/rest/config/hosttemplate/3" />
    </hosttemplates>
    <icon name="SYMBOL - Environment Monitor"
          path="/images/logos/meter_small.png" />
    <keywords>
      <item name="alphaearly"
            ref="/rest/config/keyword/6" />
      <item name="cisco"
            ref="/rest/config/keyword/2" />
      <item name="cisco_gp1"
            ref="/rest/config/keyword/3" />
    </keywords>
    <monitored_by name="Master Monitoring Server"
                  ref="/rest/config/monitoringserver/1" />
    <notification_period name="24x7"
                         ref="/rest/config/timeperiod/1" />
    <rancid_password isNull="1" />
    <rancid_username isNull="1" />
    <rancid_vendor isNull="1" />
    <servicechecks>
      <item name="Another exception"
            ref="/rest/config/servicecheck/82" />
      <item name="Coldstart"
            ref="/rest/config/servicecheck/79" />
      <item name="Interface"
            ref="/rest/config/servicecheck/95" />
      <item name="snmp poll"
            ref="/rest/config/servicecheck/83" />
      <item name="Test exceptions"
            ref="/rest/config/servicecheck/81" />
    </servicechecks>
    <snmpv3_authprotocol isNull="1" />
    <snmpv3_privprotocol isNull="1" />
</opsview>
};
$ua->put( "$url_prefix/rest/config/host/7", content => $input );
is( $ua->status, 200, "PUT OK" );
$res_data                       = $ua->content;
$expected =~ s/uncommitted="0"/uncommitted="1"/;
is_string( $res_data, $expected ) || diag( $res_data );

1;
