#!/usr/bin/perl
# Test events

use warnings;
use strict;
use FindBin qw($Bin);

use lib "$Bin/../lib";

use lib "/usr/local/nagios/lib", "/usr/local/nagios/etc", "/usr/local/nagios/t/lib";

use Test::More qw(no_plan);
use Test::Deep;

use Opsview::Test;
use Test::WWW::Mechanize;

# Run with OPSVIEW_RESET_JSON=1 perl t/733event.t to update JSON information
# Cannot add this lib before T::W::M::C
use lib "$Bin/lib";
use Opsview::TestUtils;
use Test::JSON::File;

my $ua = Test::WWW::Mechanize->new;

$ua->get_ok('http://localhost:3000/event');
$ua->content_contains( "login_form", "Have login form" );
$ua->form_name('login_form');
$ua->field( 'login_username' => "admin" );
$ua->field( 'login_password' => "initial" );
$ua->field( 'noscript'       => 0 );
$ua->click('login');
$ua->get_ok("/event");
$ua->content_contains("Events");

$ua->get_ok("/event?output=json&rows=3&cols=hostname&cols=state");
is_json_file( $ua->content, "$Bin/var/json/initial_3rows.json", "JSON output as expected: initial_3rows.json" );

$ua->get_ok("/event?output=json&rows=3&cols=hostname&cols=state&saved_maxeventid=9300");
is_json_file( $ua->content, "$Bin/var/json/initial_3rowswithsaved.json", "initial_3rowswithsaved.json" );

$ua->get_ok('/event?output=json&startTime=2009-07-29%2008:00:00&rows=5&cols=hostname&cols=state');
is_json_file( $ua->content, "$Bin/var/json/timefilter.json", "Filtered by time: timefilter.json" );

$ua->get_ok('/event?output=json&startTime=2009-07-29%2008:00:00&rows=3&endTime=2009-07-29%2009:00:00&cols=hostname&cols=state');
is_json_file( $ua->content, "$Bin/var/json/timefilterend.json", "Filtered by end time: timefilterend.json" );

$ua->get_ok('/event?output=json&startTime=2009-07-29%2008:00:00&rows=3&page=2&endTime=2009-07-29%2009:00:00&cols=hostname&cols=state');
is_json_file( $ua->content, "$Bin/var/json/timefilterendpage2.json", "Filtered by end time, page 2: timefilterendpage2.json" );

$ua->get_ok('/event?output=json&startTime=2009-07-29%2008:00:00&endTime=2009-07-29%2009:00:00&cols=hostname&cols=state');
is_json_file( $ua->content, "$Bin/var/json/export.json", "Exported json: export.json" );

$ua->get_ok('/event?output=json&page=1&rows=200&sortby=%5B%7B%22col%22%3A%20%22time%22%2C%20%22order%22%3A%20%22desc%22%7D%5D&cols=time&cols=hostname&cols=servicename&cols=state&cols=state_type&cols=output&host=resolved_services&service=VNC');
is_json_file( $ua->content, "$Bin/var/json/hostandservicefilter.json", "Host and service filter: hostandservicefilter.json" );

$ua->get_ok('/event?output=json&page=1&rows=15&sortby=%5B%7B%22col%22%3A%20%22time%22%2C%20%22order%22%3A%20%22desc%22%7D%5D&cols=time&cols=hostname&cols=servicename&cols=state&service=VNC');
is_json_file( $ua->content, "$Bin/var/json/onlyservicefilter.json", "Only service filter - should miss out host events: onlyservicefilter.json" );

$ua->get_ok('/event?output=json&page=1&rows=15&sortby=%5B%7B%22col%22%3A%20%22time%22%2C%20%22order%22%3A%20%22desc%22%7D%5D&cols=time&cols=hostname&cols=servicename&cols=state&service=VNC&saved_maxeventid=9300');
is_json_file( $ua->content, "$Bin/var/json/onlyservicefilter.json", "Same as above because saved value higher than filtered view: onlyservicefilter.json" );

$ua->get_ok('/event?output=json&page=1&rows=15&sortby=%5B%7B%22col%22%3A%20%22time%22%2C%20%22order%22%3A%20%22desc%22%7D%5D&cols=time&cols=hostname&cols=servicename&cols=state&service=VNC&saved_maxeventid=9100');
is_json_file( $ua->content, "$Bin/var/json/onlyservicefilterwithsaved.json", "onlyservicefilterwithsaved.json" );

my $somehosts = Test::WWW::Mechanize->new;
log_in( $somehosts, "somehosts", "somehosts", "http://localhost:3000" );
$somehosts->get_ok("http://localhost:3000/event");
$somehosts->content_contains("Leaf2", "Host group leaf2 listed" );
$somehosts->content_lacks("singlehost", "And singlehost is missing correctly");

my $nonadmin = Test::WWW::Mechanize->new;
log_in( $nonadmin, "nonadmin", "nonadmin", "http://localhost:3000" );
$nonadmin->get_ok("http://localhost:3000/event");
$nonadmin->content_contains("Leaf2", "Get Leaf2, as the nonadmin user have all_hostgroups listed" ) || diag($nonadmin->content);
$nonadmin->content_contains("singlehost", "Also singlehost");

