#!/usr/bin/perl

use warnings;
use strict;
use FindBin qw($Bin);
use lib "$Bin/../lib";

use lib "/usr/local/nagios/lib", "/usr/local/nagios/etc", "/usr/local/nagios/t/lib";

use Test::More qw(no_plan);
use Test::Deep;

use Opsview::Test qw(opsview);
use Test::WWW::Mechanize;

use Opsview::Test qw(opsview);
use lib "$Bin/lib";
use Opsview::TestUtils;

use Opsview::Schema;
my $schema = Opsview::Schema->my_connect;

my $mech = Test::WWW::Mechanize->new;

log_in( $mech, 'somehosts', 'somehosts', "http://localhost:3000" );

$mech->get_ok("/user/preference");
$mech->form_name("main_form");

$mech->follow_link( text => "List notification profiles" );
like( $mech->uri, qr%/user/notificationprofile$%, "Good url" );
$mech->content_contains("Non work hours sms", "Have list for 1st notification profile" );
$mech->content_contains("Default", "And 2nd too" );

$mech->follow_link( text => "Non work hours sms" );
$mech->form_name( "main_form" );

$mech->content_contains("Operations", "Got service group list" );
$mech->content_contains("Leaf2", "Got host group list");

$mech->get_ok("/user/notificationprofile/new");
$mech->form_name("main_form");
$mech->field("name", "Testing123");
$mech->submit;

is($mech->status, 200);
$mech->content_contains(qq{<meta http-equiv="refresh" content="0; URL=/user/notificationprofile" />}, "Goes back to list page");

$mech->get_ok("/user/notificationprofile");
$mech->content_contains("Testing123", "Got new item");
$mech->content_contains("Non work hours sms", "...as well as old items too");

$mech->get("/user/notificationprofile/edit/7");
is( $mech->status, 403, "Should not be able to read someone else's notification profile");
$mech->get("/user/notificationprofile/clone/7");
is( $mech->status, 403, "Should not be able to clone someone else's notification profile");
$mech->get("/user/notificationprofile/delete/13");
is( $mech->status, 403, "Get access denied trying to delete someone else's notification profile" );

# Check reordering filters the notification profiles to allowed ones
$mech->get("/user/notificationprofile/set_order?list[]=14&list[]=13&list[]=12&list[]=11&list[]=10&list[]=4");
my $rs = $schema->resultset("Notificationprofiles");
is( $rs->find(14)->priority, 1, "First okay" );
is( $rs->find(12)->priority, 2, "2nd okay" );
is( $rs->find(4)->priority, 3, "3rd okay" );

is( $rs->find(13)->priority, 1, "Not changed for others" );
is( $rs->find(11)->priority, 1, "Not changed for others" );
is( $rs->find(10)->priority, 2, "Not changed for others" );

1;
