#!/usr/bin/perl
# Test contact edit pages

use warnings;
use strict;
use FindBin qw($Bin);
use lib "$Bin/../lib";

use lib "/usr/local/nagios/lib", "/usr/local/nagios/etc", "/usr/local/nagios/t/lib";

use Test::More qw(no_plan);
use Test::Deep;
use Test::LongString;

use Opsview::Test qw(opsview);
use Test::WWW::Mechanize::Catalyst qw(Opsview::Web);

use lib "$Bin/lib";
use Opsview::TestUtils;

use Data::Dump qw(dump);

my $content;
my $ua = Test::WWW::Mechanize::Catalyst->new;

log_in( $ua, 'admin', 'initial' );

$ua->get_ok("/admin/contact?q=adminnoc");
$ua->content_contains("No notifications allowed", "Help message due to no NOTIFYSOME access");

$ua->get_ok("/admin/contact?q=onlyunknowns");
$ua->content_contains("No notifications configured", "Text re: no notifications" );
is( $ua->find_link( text => "No notifications configured" )->url, "/admin/notificationprofile/new?contact=5", "Got link to create new notification profile" );

$ua->get_ok("/admin/contact/edit/1");
$ua->form_name("main_form");
$ua->click_button( value => "Submit Changes" );
$ua->content_like( qr^URL=http://localhost/admin/contact^, "Redirected back to list page" );

$ua->get_ok("/admin/contact/edit/1");
$ua->content_contains("Swedish", "Got languages in edit contact page");
$ua->form_name("main_form");
$ua->click_button( value => "Submit and Edit Notification Profiles" );
$ua->content_like(qr^URL=/admin/notificationprofile\?contact=1^, "Redirected to notification profiles" );

$ua->get_ok("/admin/contact");
$ua->get_ok("/admin/contact/new");
$ua->form_name("main_form");
$ua->field( "name", "test455" );
$ua->field( "fullname", "test455" );
$ua->click_button( value => "Submit Changes" );
$ua->content_like( qr^URL=http://localhost/admin/contact^, "Redirected back to list page on create" );

$ua->get_ok("/admin/contact/new");
$ua->content_contains("Swedish", "Got languages in new contact page");
$ua->form_name("main_form");
$ua->field( "name", "test456" );
$ua->field( "fullname", "test456" );
$ua->click_button( value => "Submit and Edit Notification Profiles" );
$ua->content_like(qr^URL=/admin/notificationprofile\?contact=1^, "Redirected to notification profiles on create" )
|| diag($ua->content);


note("Testing email field problem - OPS-1255");
$ua->get_ok("/admin/notificationmethods/edit/1", "Unticking AQL notification method");
$ua->form_name("main_form");
$ua->untick("active", 1);
$ua->current_form->action;
$ua->submit;

$ua->get_ok("/admin/notificationmethods/edit/4", "Unticking RSS notification method");
$ua->form_name("main_form");
$ua->untick("active", 1);
$ua->current_form->action;
$ua->submit;

$ua->get_ok("/admin/contact/edit/1", "Checking for email field" );
$ua->content_contains( "email", "Has email field" );

$ua->get_ok("/admin/contact/clone/1", "Load clone page" );
$ua->content_contains( "Swedish", "Has languages on clone page" );
