#!perl

use warnings;
use strict;

use FindBin qw($Bin);
use lib "$Bin/../lib";
use lib "/usr/local/nagios/lib";

use Test::WWW::Mechanize::Catalyst qw(Opsview::Web);
use HTTP::Cookies;
use Sys::Hostname;


use Opsview;
use Opsview::Contact;

use lib "$Bin/lib";
use Opsview::Web::Test;
use Opsview::TestUtils;

use Test::More qw(no_plan);
use Test::Deep;

my $ua = Test::WWW::Mechanize::Catalyst->new();

# No cookies here - should get login page
log_in( $ua, "admin", "initial" );

$ua->get("/status/host?hostgroupid=6&host_filter=unhandled");
ok( $ua->res->is_success, "Got HH host list page" );
like( $ua->res->content, "/No matching hosts/", "Correct no hosts listed" );

$ua->get("/status/service?hostgroupid=6&filter=handled");
ok( $ua->res->is_success, "Got HH service list page" );
like( $ua->res->content, "/No matching services/", "Correct no services listed" );

$ua->get("/status/service?host=cisco");
ok( $ua->res->is_success, "Got service list page for cisco" );
like( $ua->res->content, "/Test exceptions/", "Got service for Test exceptions" );

$ua->get("/status/service?host=cisco1&host=cisco2");
ok( $ua->res->is_success, "Got service list page for cisco1 and cisco2" );
like( $ua->res->content, "/Test exceptions/", "Got service for Test exceptions" );

my $link = $ua->find_link( url => "http://opsview1.org" );
isa_ok( $link, "WWW::Mechanize::Link", "Which means markdown conversion is working" );

$link = $ua->find_link( url => "http://opsview2.org" );
is( $link, undef, "No link to opsview2.org" );
$ua->content_contains("http://opsview2.org", "...even though the string exists");

$ua->get("/status/service?host=cisco&asuser=somehosts");
ok( $ua->res->is_success, "Got service list page for cisco" );
like( $ua->res->content, qr%No matching services%, "No services found...." );
like( $ua->res->content, qr%<div id='filter_box'>Host: cisco<br/></div>%, "But is in filter box" );

$ua->get("/status/service?host=cisco&asuser=somehosts666");
like( $ua->res->content, "/Contact somehosts666 not found/", "Invalid asuser parameter" );

$ua->get("/status/hostgroup/3");
ok( $ua->res->is_success, "Got HH for hostgroup 3" );
like( $ua->res->content, "/Leaf/", "With Leaf hostgroup" );

$ua->get("/status/hostgroup/3?asuser=somehosts");
ok( $ua->res->is_success, "Got HH for hostgroup 3 with somehosts user" );
unlike( $ua->res->content, "/Leaf/", "Without Leaf hostgroup" );

# This regex allows Ajax.Updater to be on a different line
# as long as there is no close bracket before the URL
like( $ua->res->content, qr{Ajax.Updater\([^\)]*'/status/hostgroup/3\?asuser=somehosts&output=ajax'}s, "Refresh button correct" );

# No cookies here - should get login page
my $somehosts = Test::WWW::Mechanize::Catalyst->new();
log_in( $somehosts, "somehosts", "somehosts" );

$somehosts->get("/status/hostgroup");
ok( $somehosts->res->is_success, "Got HH for hostgroup with somehosts user" );
like( $somehosts->res->content, "/UK/", "With UK hostgroup" );
my $content = $somehosts->res->content;
is( $content =~ /UK/, 1, "Once!" );

$somehosts->get_ok("/status/hostgroup/name/UK2");
is( $somehosts->uri."", "http://localhost/status/hostgroup?parentid=6", "URL redirected" );

$somehosts->get_ok("/status/hostgroup/name/UK");
$somehosts->content_contains("Host group UK not found", "User correctly has no access to this hostgroup");

$somehosts->get("/status/hostgroup?asuser=admin");
ok( $somehosts->res->is_success, "Got HH for hostgroup - ignored asuser parameter" );
$content = $somehosts->res->content;
is( $content =~ /UK/, 1, "Still once!" );
