#!perl
#
# Tests to ensure nmis cgis work, and that authentication is limited to admin users

use warnings;
use strict;

use FindBin qw($Bin);
use lib "$Bin/../lib";
use lib "/usr/local/nagios/lib";

use Test::WWW::Mechanize::Catalyst qw(Opsview::Web);
use HTTP::Cookies;
use Sys::Hostname;

use Opsview;
use Opsview::Contact;

use lib "$Bin/lib";
use Opsview::Web::Test;
use Opsview::TestUtils;

use Test::More qw(no_plan);
use Test::Deep;

my $ua = Test::WWW::Mechanize::Catalyst->new();
my $cj = HTTP::Cookies->new();
$ua->cookie_jar($cj);

my $hostname = Sys::Hostname::hostname;
$hostname = "localhost:3000";

# No cookies here - should get login page
log_in( $ua, "admin", "initial" );

$ua->get("http://$hostname/cgi-nmis/nmiscgi.pl");
ok( $ua->res->is_success, "Got NMIS front page" );
like( $ua->res->content, "/NMIS via Opsview/", "Got NMIS detail" );

note("Check for security - OPS-1379");
$ua->get_ok("/cgi-nmis/admin.pl?admin=ping&node=127.0.0.1");
$ua->content_contains("packets transmitted", "Got ping output as normal" );
$ua->get_ok("/cgi-nmis/admin.pl?admin=ping&node=127.0.0.1+%7C+ls+-1");
$ua->content_lacks("README", "Definitely didn't get any output from ls -l");

$ua->get("/logout");

ok( $ua->res->is_success, "Should get login page" );
like( $ua->content, "/login_username/s", "Returned login_username, so is a login page" );

$ua->get("http://$hostname/cgi-nmis/nmiscgi.pl");
ok( $ua->res->is_success, "Should get login page" );

$ua->field( 'login_username', 'nonadmin' );
$ua->field( 'login_password', 'nonadmin' );
$ua->field( "noscript" => 0 );
$ua->field( 'back', "http://$hostname/cgi-nmis/nmiscgi.pl" );    # Not sure why I need this, because browser works fine
$ua->current_form->action;
$ua->submit;

ok( $ua->res->is_success, "Got page, but ..." );
like( $ua->content, "/access denied/i", "Didn't get access because non admin user" );
