#!/usr/bin/perl

use warnings;
use strict;
use FindBin qw($Bin);
use lib "$Bin/../lib";
use File::Next;
use File::Basename;

use lib "/usr/local/nagios/lib", "/usr/local/nagios/etc", "/usr/local/nagios/t/lib";

use Test::More;

plan "no_plan";

use Opsview::Test qw(opsview);
use Test::WWW::Mechanize::Catalyst qw(Opsview::Web);
use Log::Log4perl;
use Log::Log4perl::Level;
# reduce unnecessary output by amending rootlogger to suppress INFO and DEBUG messages
Log::Log4perl->get_logger("")->level($WARN);

# Copy mrtg files over, so this should work on different systems too
system("cp $Bin/var/mrtg.cfg /usr/local/nagios/etc/mrtg.cfg") == 0 or die "Copy mrtg.cfg failure: $!";

# use dump files to ensure tests work correctly on amd64 servers
my $file_filter = sub { $_ && $_ =~ m/\.xml$/ };
my $rrd_xml = File::Next::files( { file_filter => $file_filter, }, "$Bin/var/mrtg" );
while ( defined( my $dump = $rrd_xml->() ) ) {
    my ( $filename, $dir, $suffix ) = fileparse( $dump, qr/\.xml$/ );
    system("rrdtool restore -f '$dump' '/usr/local/nagios/var/mrtg/$filename.rrd'") == 0 or die 'rrdtool restore failure: ', $!;
}

my $mech = Test::WWW::Mechanize::Catalyst->new;

$mech->get_ok("http://localhost/status/network_traffic");

$mech->content_like( qr/login_username/, "Login page" );

$mech->form_name('login_form');
$mech->field( 'login_username' => "admin" );
$mech->field( 'login_password' => "initial" );
$mech->field( "noscript"       => 0 );
$mech->click('login');

$mech->content_like(qr/Network Traffic/);

my $mrtg_link = $mech->find_link( text => "MRTG Graphs", n => 1 );
is( $mrtg_link->url, "http://opslaveclusterAip/cgi-bin/mrtg-rrd.cgi/?host=monitored_by_clusterip", "Right link for cluster" );

$mrtg_link = $mech->find_link( text => "MRTG Graphs", n => 2 );
is( $mrtg_link->url, "http://opslave/cgi-bin/mrtg-rrd.cgi/?host=monitored_by_slave", "Right link for single node slave" );

my $opsviewdev1_link = $mech->find_link( text => "MRTG Graphs", n => 3 );
is( $opsviewdev1_link->url, "/cgi-bin/mrtg-rrd.cgi/?host=opsviewdev1.der.altinity", "Right link" );

my $opsviewdev46_link = $mech->find_link( text => "MRTG Graphs", n => 4 );
is( $opsviewdev46_link->url, "/cgi-bin/mrtg-rrd.cgi/?host=192.168.101.46", "Right link" );

$mech->get_ok( $opsviewdev1_link->url );
$mech->content_like( "/No such host: opsviewdev1.der.altinity/", "Correctly list no MRTG RRDs for this host" );

$mech->get_ok( $opsviewdev46_link->url );
my ( $if1, $if2, $if3 ) = $mech->find_all_links( tag => "a" );
is( $if1->url, "192.168.101.46_gigabitethernet1_0_3.html", 'itf1 - url ok' );
is( $if2->url, "192.168.101.46_3.html",                    'itf2 - url ok' );
is( $if3->url, "192.168.101.46_dev3_(slot_1_port_1).html", 'itf3 - url ok' );

my ( $img1, $img2, $img3 ) = $mech->find_all_images();
is( $img1->url, "192.168.101.46_gigabitethernet1_0_3-day.png", 'img1 - image ok' );
is( $img2->url, "192.168.101.46_3-day.png",                    'img2 - image ok' );
is( $img3->url, "192.168.101.46_dev3_(slot_1_port_1)-day.png", 'img3 - image ok' );

$mech->get( $img1->url );
is( $mech->ct, "image/png", "Got image back" );

$mech->back;
$mech->get( $img2->url );
is( $mech->ct, "image/png", "Got image back" );

$mech->back;
$mech->get( $img3->url );
is( $mech->ct, "image/png", "Got image back" );

$mech->back;

1;
