#!/usr/bin/perl

use warnings;
use strict;
use FindBin qw($Bin);
use lib "$Bin/../lib";

use lib "/usr/local/nagios/lib", "/usr/local/nagios/etc", "/usr/local/nagios/t/lib";

use Test::More qw(no_plan);
use Test::Deep;

use Test::WWW::Mechanize::Catalyst qw(Opsview::Web);
use lib "$Bin/lib";
use Opsview::TestUtils;

my $mech = Test::WWW::Mechanize->new;

log_in( $mech, 'admin', 'initial', "http://localhost:3000" );

$mech->get_ok("/status/hostgroup", "Got top level host group hierarchy");
$mech->follow_link( text => "UK");
$mech->title_is("Opsview > Host Group Summary > UK", "Got one level down");
$mech->follow_link( text => "Mass Re-checks" );
$mech->content_contains( "opslave", "Has got opslave host" );
$mech->content_lacks("monitored_by_slave", "But should not have monitored_by_slave") || diag($mech->content);


# Do some total checks
$mech->get_ok("/status/hostgroup", "From HH....");
$mech->follow_link_ok( { text => "UK" }, "Goto UK ..." );
$mech->content_contains( '<tr class="summary first"><td rowspan="3" class="heading">Totals</td><td>9</td><td>1</td><td>6</td><td>17</td></tr><tr class="summary"><td colspan="2"><div class="up">8&nbsp;UP</div><div class="down">2&nbsp;DOWN</div></td><td colspan="2"><div class="ok">3&nbsp;OK</div><div class="unknown">18&nbsp;UNKNOWN</div><div class="critical">2&nbsp;CRITICAL</div></td></tr><tr class="summary"><td colspan="2">10</td><td colspan="2">23</td></tr>', "Got right list of things" );

$mech->follow_link_ok({ url_regex => qr%/status/host\?(host_filter=handled&hostgoupid=3|hostgroupid=3&host_filter=handled)% }, "... goto host handled" );
$mech->content_contains( '<tr class="summary first"><td rowspan="3" class="heading">Totals</td><td>9</td>' );
$mech->content_contains( '8&nbsp;UP' );
$mech->content_contains( '1&nbsp;DOWN' );
$mech->content_contains( '2&nbsp;OK' );
$mech->content_contains( '17&nbsp;UNKNOWN' );
$mech->content_contains( '2&nbsp;CRITICAL' );
$mech->follow_link_ok( { text => "Mass Re-checks" } );
$mech->content_contains( '<tr class="summary first"><td class="heading">Totals</td><td>21</td>' );
$mech->back;
$mech->back;

$mech->follow_link_ok({ url_regex => qr%/status/host\?(host_filter=unhandled&hostgoupid=3|hostgroupid=3&host_filter=unhandled)% }, "... goto host unhandled" );
$mech->content_contains( '<tr class="summary first"><td rowspan="3" class="heading">Totals</td><td></td><td>1</td><td>2</td><td></td>' );
$mech->content_contains( '1&nbsp;DOWN' );
$mech->follow_link_ok( { text => "Mass Re-checks" } );
$mech->content_contains( '<tr class="summary first"><td class="heading">Totals</td><td>2</td>' );
$mech->back;
$mech->back;

$mech->follow_link_ok({ url_regex => qr%/status/service\?(filter=handled&hostgoupid=3|hostgroupid=3&filter=handled)% }, "... goto service handled" );
$mech->content_contains( '<tr class="summary first"><td class="heading">Totals</td><td>6</td>' );
$mech->content_contains( '3&nbsp;OK' );
$mech->content_contains( '3&nbsp;UNKNOWN' );
$mech->follow_link_ok( { text => "Mass Re-checks" } );
$mech->content_contains( '<tr class="summary first"><td class="heading">Totals</td><td>6</td>' );
$mech->back;
$mech->back;

$mech->follow_link_ok({ url_regex => qr%/status/service\?(filter=unhandled&hostgoupid=3|hostgroupid=3&filter=unhandled)% }, "... goto service unhandled" );
$mech->content_contains( '<tr class="summary first"><td class="heading">Totals</td><td>17</td>' );
$mech->content_contains( '15&nbsp;UNKNOWN' );
$mech->content_contains( '2&nbsp;CRITICAL' );
$mech->follow_link_ok( { text => "Mass Re-checks" } );
$mech->content_contains( '<tr class="summary first"><td class="heading">Totals</td><td>17</td>' );
$mech->back;
$mech->back;





$mech->get_ok("/status/service?host=opslave");
$mech->follow_link( url_regex => qr%/recheck% );
$mech->content_contains("1&nbsp;OK");

$mech->form_name("recheck_form");
$mech->tick( "service_selection", "opslave;/" );
$mech->submit_form;

$mech->content_contains("Re-checks submitted for hosts: 0, services: 1");

open F, "/usr/local/nagios/var/rw/nagios.cmd";
my @contents = <F>;
close F;
is( scalar @contents, 1 );
like( $contents[0], qr^SCHEDULE_SVC_CHECK;opslave;/;^ );
open F, "> /usr/local/nagios/var/rw/nagios.cmd";
close F;

$mech->get_ok("/status/service?host=monitored_by_slave");
$mech->follow_link( url_regex => qr%/recheck% );
$mech->content_contains("2&nbsp;UNKNOWN");
$mech->content_contains("1&nbsp;CRITICAL");
$mech->content_contains('name="sidenav"');

$mech->form_name("recheck_form");
$mech->tick( "host_selection",    "monitored_by_slave" );
$mech->tick( "service_selection", "monitored_by_slave;/" );
$mech->tick( "service_selection", "monitored_by_slave;VNC" );
$mech->submit_form;

$mech->content_contains("Re-checks submitted for hosts: 1, services: 2");

open F, "/usr/local/nagios/var/rw/nagios.cmd";
@contents = <F>;
close F;
open F, "> /usr/local/nagios/var/rw/nagios.cmd";
close F;
is( scalar @contents, 3 );
like( $contents[0], qr^SCHEDULE_HOST_CHECK;monitored_by_slave;^ );
like( $contents[1], qr^SCHEDULE_SVC_CHECK;monitored_by_slave;/;^ );
like( $contents[2], qr^SCHEDULE_SVC_CHECK;monitored_by_slave;VNC;^ );

# Somehosts user shouldn't see opsview host
my $somehosts = Test::WWW::Mechanize::Catalyst->new;
log_in( $somehosts, "somehosts", "somehosts" );
$somehosts->get_ok("/status/service/recheck?host=opslave");
$somehosts->content_contains("No matching services");
