package Opsview::Test::FileContents;

use warnings;
use strict;

use Exporter;
use base 'Exporter';

our @EXPORT = qw(file_contents_compare file_contents_differ);

use Test::Builder;
use Test::More;

my $Test = Test::Builder->new;

sub file_contents_differ {
    my ( $string, $expected_file, $desc ) = @_;
    my $temp_file = _write_temp_file(@_);
    if ( _file_compares_same( $temp_file, $expected_file ) ) {
        $Test->diag("Files are the same between $temp_file and $expected_file");
        $Test->diag("If this is okay, run: cp $temp_file $expected_file");
        $Test->ok( 0, $desc );
        return 0;
    }
    else {
        $Test->ok( 1, $desc );
        return 1;
    }
}

sub file_contents_compare {
    my ( $string, $expected_file, $desc ) = @_;
    my $temp_file = _write_temp_file(@_);
    if ( _file_compares_same( $temp_file, $expected_file ) ) {
        $Test->ok( 1, $desc );
        return 1;
    }
    else {
        $Test->diag("Difference between $temp_file and $expected_file");
        $Test->diag("If okay, run: cp $temp_file $expected_file");
        $Test->ok( 0, $desc );
        return 0;
    }
}

sub _write_temp_file {
    my ( $string, $expected_file ) = @_;
    my $short_filename = $expected_file;
    $short_filename =~ s/.*\///g;
    my $temp_file = "/tmp/$short_filename" . $$ . "." . int( rand(10000) );
    open F, "> $temp_file" or die "Error opening $temp_file: $!";
    print F $string;
    close F;
    return $temp_file;
}

sub _file_compares_same {
    my ( $temp_file, $expected_file ) = @_;
    my @command = ( "diff", "-u", $temp_file, $expected_file );
    note("diff command: @command");
    if ( system("@command > /dev/null") != 0 ) {
        return 0;
    }
    else {
        return 1;
    }
}

1;
