#
#
# AUTHORS:
#	Copyright (C) 2003-2011 Opsera Limited. All rights reserved
#
#    This file is part of Opsview
#
#    Opsview is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Opsview is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Opsview; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#

# Start this up after Test::WWW::Mechanize::Catalyst
# use lib "$Bin/lib";
# use Opsview::TestUtils

package Opsview::TestUtils;
use warnings;
use strict;

use Exporter;
use Log::Log4perl;
use Log::Log4perl::Level;

use base 'Exporter';

our @EXPORT = qw(log_in log_out witter rest_log_in);

use Test::More;

# reduce unnecessary output by amending rootlogger to suppress INFO and DEBUG messages
Log::Log4perl->get_logger("")->level($WARN);

sub witter {
    Test::More::diag(@_) if ( $ENV{TEST_VERBOSE} );
}

sub log_in {
    my ( $mech, $user, $pass, $url_prefix ) = @_;
    witter("Logging in as $user") if ( $ENV{VERBOSE_TESTS} );
    $url_prefix ||= "http://localhost";
    $mech->get_ok("$url_prefix/");
    $mech->form_name('login_form') || diag( "Can't find login_form. Page contents: " . $mech->content );
    $mech->field( 'login_username' => $user );
    $mech->field( 'login_password' => $pass );

    # Always force noscript to 0 to avoid the "no javascript" error
    $mech->field( 'noscript' => 0 );
    $mech->click('login');
    $mech->content_like(qr/Host Group Summary/) || diag( $mech->content );

}

sub log_out {
    my ($mech) = @_;
    $mech->get_ok("http://localhost/logout");
    $mech->content_like(qr/Please log in/);
}

sub nagioscmds {
    open F, "/usr/local/nagios/var/rw/nagios.cmd";
    my @contents = <F>;
    close F;
    return @contents;
}

sub rest_log_in {
    my ( $mech, $user, $pass ) = @_;
    witter("Logging in as $user") if ( $ENV{VERBOSE_TESTS} );
    $mech->add_header( 'content-type' => 'text/x-data-dumper' );
    $mech->post( "http://localhost:3000/rest/login", Content => "{ username => $user, password => $pass }" );
    is( $mech->status, 200, "Logged in to REST okay" ) || die( "Rest login failure. Full content: " . $mech->content );
    my $content = eval $mech->content;
    $mech->add_header( "X-Opsview-Username" => $user );
    $mech->add_header( "X-Opsview-Token"    => $content->{token} );
}

1;
